@@ -1009,9 +1009,17 @@ class EnvBase(ABC):
             bnTKN_value (int or float or decimal): value of a single bnTKN pool token.
         """
         spot_rate = self.get_spot_rate(tkn)
+        spot_rate = self.validate_type(spot_rate)
+
         ema = self.ema[tkn]['ema'][-1]
+        ema = self.validate_type(ema)
+
+        lower_limit = self.validate_type(lower_limit)
+        upper_limit = self.validate_type(upper_limit)
+
         lower_bound = self.tokenomics.handle_multiplication(lower_limit, ema)
         upper_bound = self.tokenomics.handle_multiplication(upper_limit, ema)
+
         result = lower_bound <= spot_rate <= upper_bound
         if self.verbose:
             print(
